==> pyphant.imageprocessing-0.8a2.tar.gz: pyphant.imageprocessing-0.8a2/ImageProcessing/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2006-2007, Rectorate of the University of Freiburg
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright
#   notice, this list of conditions and the following disclaimer.
# * Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in the
#   documentation and/or other materials provided with the distribution.
# * Neither the name of the Freiburg Materials Research Center,
#   University of Freiburg nor the names of its contributors may be used to
#   endorse or promote products derived from this software without specific
#   prior written permission.
#
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
# OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

u"""
The ImageProcessing toolbox holds workers to process data resulting from scalar fields.
"""

__id__ = "$Id$"
__author__ = "$Author$"
__version__ = "$Revision$"
# $Source$

BACKGROUND_COLOR=255
FEATURE_COLOR=0

workers=[
    "ApplyMask",
    "AutoFocus",
    "CoverageWorker",
    "DiffWorker",
    "DistanceMapper",
    "EdgeFillWorker",
    "EdgeTouchingFeatureRemover",
    "EnhanceContrast",
    "FilterWorker",
    "FindLocalExtrema",
    "FitBackground",
    "Gradient",
    "ImageLoaderWorker",
    "InvertWorker",
    "MarkAF",
    "Medianiser",
    "NDImageWorker",
    "SkeletonizeFeature",
    "SliceSelector",
    "ThresholdingWorker",
    "UltimatePointsCalculator",
    "Watershed",
    "Reduce",
    "FeatureRatio"
    ]

def isFeature(point):
    if point == FEATURE_COLOR:
        return True
    else:
        return False

==> pyphant.imageprocessing-1.0b2.tar.gz: pyphant.imageprocessing-1.0b2/ImageProcessing/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2006-2007, Rectorate of the University of Freiburg
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright
#   notice, this list of conditions and the following disclaimer.
# * Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in the
#   documentation and/or other materials provided with the distribution.
# * Neither the name of the Freiburg Materials Research Center,
#   University of Freiburg nor the names of its contributors may be used to
#   endorse or promote products derived from this software without specific
#   prior written permission.
#
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
# OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

u"""
The ImageProcessing toolbox holds workers to process data
resulting from scalar fields.
"""


BACKGROUND_COLOR=255
FEATURE_COLOR=0

workers=[
    "ApplyMask",
    "AutoFocus",
    "CoverageWorker",
    "DiffWorker",
    "DistanceMapper",
    "EdgeFillWorker",
    "EdgeTouchingFeatureRemover",
    "EnhanceContrast",
    "FindLocalExtrema",
    "FitBackground",
    "Gradient",
    "ImageLoaderWorker",
    "InvertWorker",
    "LoadZStack",
    "MarkInclusions",
    "Medianiser",
    "SkeletonizeFeature",
    "ThresholdingWorker",
    "UltimatePointsCalculator",
    "Watershed",
    ]

def isFeature(point):
    if point == FEATURE_COLOR:
        return True
    else:
        return False
